文件操作 - implementation.js
返回文件管理
返回主菜单
删除本文件
文件: /usr/share/atom/resources/app/apm/node_modules/ext/global-this/implementation.js
编辑文件内容
var naiveFallback = function () { if (typeof self === "object" && self) return self; if (typeof window === "object" && window) return window; throw new Error("Unable to resolve global `this`"); }; module.exports = (function () { if (this) return this; // Unexpected strict mode (may happen if e.g. bundled into ESM module) // Thanks @mathiasbynens -> https://mathiasbynens.be/notes/globalthis // In all ES5+ engines global object inherits from Object.prototype // (if you approached one that doesn't please report) try { Object.defineProperty(Object.prototype, "__global__", { get: function () { return this; }, configurable: true }); } catch (error) { // Unfortunate case of Object.prototype being sealed (via preventExtensions, seal or freeze) return naiveFallback(); } try { // Safari case (window.__global__ is resolved with global context, but __global__ does not) if (!__global__) return naiveFallback(); return __global__; } finally { delete Object.prototype.__global__; } })();
修改文件时间
将文件时间修改为当前时间的前一年
删除文件